/**
 *  @file blinker.c
 *  Blinker driver ported from Jon McPhalen's blinker.spin
 *  Copyright (c) 2021, Jon McPhalen
 *  See end of file for MIT license terms.
 */

#include <propeller.h>
#include <stdint.h>
#include "blinker.h"


static int bcog; 
static HUBDATA blinker_st gblinker;


/**
 *  Start blinker driver
 *  see header for API description.
 */

int blinker_start(uint32_t pin, uint32_t onms, uint32_t offms)
{
    extern unsigned int *binary_blinker_dat_start;

    blinker_stop();
    gblinker.blinkpin = pin;
    gblinker.onticks = CLKFREQ /1000 * onms;
    gblinker.offticks = CLKFREQ /1000 * offms;
    bcog = cognew(&binary_blinker_dat_start, (uint32_t *)&gblinker) + 1;

    return bcog;
}


/**
 *  Stop blinker driver
 *  see header for API description.
 */
void blinker_stop(void)
{
    int cog = bcog - 1;

    if(bcog > 0) {
        cogstop(cog);
        bcog = 0;
    }
}


/**
 *  Return blinker status
 *  see header for API description.
 */
int blinker_active(void)
{
    return bcog;  
}


/**
 * ----------------------------------------------------------------------------
 *                        TERMS OF USE: MIT License
 * ----------------------------------------------------------------------------
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 * ----------------------------------------------------------------------------
 */