/**
 *  @file blinker.h
 *  Blinker driver header & API descriptions.
 *  Copyright (c) 2012, Jon McPhalen
 *  See end of file for MIT license terms.
 */

#ifndef __BLINKER_H__
#define __BLINKER_H__

#include <stdint.h>


/**
 *  Blinker driver interface structure
 */
typedef volatile struct blinker_struct
{
    uint32_t blinkpin;
    uint32_t onticks;
    uint32_t offticks; 
} blinker_st;


/**
 *  Start blinker driver - starts a cog
 *  @return cog number or 0 if no cog available
 */
int blinker_start(uint32_t pin, uint32_t onms, uint32_t offms);


/**
 *  Stop blinker driver - frees cog
 */
void blinker_stop(void);


/**
 *  Blinker activity status
 *  @return cog number or 0 if not active
 */
int blinker_active(void);


#endif
// __BLINKER_H__


/**
 * ----------------------------------------------------------------------------
 *                        TERMS OF USE: MIT License
 * ----------------------------------------------------------------------------
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 * ----------------------------------------------------------------------------
 */